==> connector-client-1.0.0-20230323.093001-2-sources.jar: com/daas/nros/connector/model/vo/MemberLoginResponseVO.java <==
package com.daas.nros.connector.model.vo;

import com.bizvane.connectorservice.entity.base.BaseModel;
import lombok.ToString;

/**
 * @author liuying
 * @date 2018/8/9
 * @description
 */
@ToString
public class MemberLoginResponseVO extends BaseModel {
    /**
     * 等级code
     */
    private String levelCode;

    /**
     * 等级name
     */
    private String levelName;

    /**
     * 线下卡号
     */
    private String offlineCardNo;

    /**
     * 当前累计可用积分
     */
    private Integer countIntegral;

    /**
     * 会员卡有效期 pattern = "yyyyMMdd"
     */
    private String effectiveTime;

    /**
     * 会员姓名
     */
    private String name;

    /**
     * 会员性别(1男   0女)
     */
    private Integer gender;

    /**
     * 会员生日 pattern = "yyyyMMdd"
     */
    private String birthday;

    /**
     * 省份
     */
    private String province;

    /**
     * 城市
     */
    private String city;

    /**
     * 区县
     */
    private String county;

    /**
     * 详细地址
     */
    private String address;

    /**
     * 开卡门店编号
     */
    private String openStoreCode;

    /**
     * 开卡导购编号
     */
    private String openGuideCode;

    /**
     * 是否首次登陆,0是第一次
     */
    private Integer firstLandingCheck;

    /**
     * 线下会员Id
     */
    private String erpId;

    private String openCardTime;

    /**
     * 会员身份证号
     */
    private String idCard;

    /**
     * 余额
     */
    private String balance;

    /**
     * 绑定状态1 .已绑定2.未绑定3.未注册
     */
    private Integer bindType;

    public String getLevelName() {
        return levelName;
    }

    public void setLevelName(String levelName) {
        this.levelName = levelName;
    }

    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }

    public String getBalance() {
        return balance;
    }

    public void setBalance(String balance) {
        this.balance = balance;
    }

    public Integer getBindType() {
        return bindType;
    }

    public void setBindType(Integer bindType) {
        this.bindType = bindType;
    }

    public String getLevelCode() {
        return levelCode;
    }

    public void setLevelCode(String levelCode) {
        this.levelCode = levelCode;
    }

    public String getOfflineCardNo() {
        return offlineCardNo;
    }

    public void setOfflineCardNo(String offlineCardNo) {
        this.offlineCardNo = offlineCardNo;
    }

    public Integer getCountIntegral() {
        return countIntegral;
    }

    public void setCountIntegral(Integer countIntegral) {
        this.countIntegral = countIntegral;
    }

    public String getEffectiveTime() {
        return effectiveTime;
    }

    public void setEffectiveTime(String effectiveTime) {
        this.effectiveTime = effectiveTime;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Integer getGender() {
        return gender;
    }

    public void setGender(Integer gender) {
        this.gender = gender;
    }

    public String getBirthday() {
        return birthday;
    }

    public void setBirthday(String birthday) {
        this.birthday = birthday;
    }

    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }

    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }

    public String getCounty() {
        return county;
    }

    public void setCounty(String county) {
        this.county = county;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getOpenStoreCode() {
        return openStoreCode;
    }

    public void setOpenStoreCode(String openStoreCode) {
        this.openStoreCode = openStoreCode;
    }

    public String getOpenGuideCode() {
        return openGuideCode;
    }

    public void setOpenGuideCode(String openGuideCode) {
        this.openGuideCode = openGuideCode;
    }

    public Integer getFirstLandingCheck() {
        return firstLandingCheck;
    }

    public void setFirstLandingCheck(Integer firstLandingCheck) {
        this.firstLandingCheck = firstLandingCheck;
    }

    public String getErpId() {
        return erpId;
    }

    public void setErpId(String erpId) {
        this.erpId = erpId;
    }

    public String getOpenCardTime() {
        return openCardTime;
    }

    public void setOpenCardTime(String openCardTime) {
        this.openCardTime = openCardTime;
    }
}

==> connector-client-1.0.0-20230324.090846-5-sources.jar: com/daas/nros/connector/model/vo/MemberLoginResponseVO.java <==
package com.daas.nros.connector.model.vo;

import com.daas.nros.connector.model.base.BaseModel;
import lombok.ToString;

/**
 * @author liuying
 * @date 2018/8/9
 * @description
 */
@ToString
public class MemberLoginResponseVO extends BaseModel {
    /**
     * 等级code
     */
    private String levelCode;

    /**
     * 等级name
     */
    private String levelName;

    /**
     * 线下卡号
     */
    private String offlineCardNo;

    /**
     * 当前累计可用积分
     */
    private Integer countIntegral;

    /**
     * 会员卡有效期 pattern = "yyyyMMdd"
     */
    private String effectiveTime;

    /**
     * 会员姓名
     */
    private String name;

    /**
     * 会员性别(1男   0女)
     */
    private Integer gender;

    /**
     * 会员生日 pattern = "yyyyMMdd"
     */
    private String birthday;

    /**
     * 省份
     */
    private String province;

    /**
     * 城市
     */
    private String city;

    /**
     * 区县
     */
    private String county;

    /**
     * 详细地址
     */
    private String address;

    /**
     * 开卡门店编号
     */
    private String openStoreCode;

    /**
     * 开卡导购编号
     */
    private String openGuideCode;

    /**
     * 是否首次登陆,0是第一次
     */
    private Integer firstLandingCheck;

    /**
     * 线下会员Id
     */
    private String erpId;

    private String openCardTime;

    /**
     * 会员身份证号
     */
    private String idCard;

    /**
     * 余额
     */
    private String balance;

    /**
     * 绑定状态1 .已绑定2.未绑定3.未注册
     */
    private Integer bindType;

    public String getLevelName() {
        return levelName;
    }

    public void setLevelName(String levelName) {
        this.levelName = levelName;
    }

    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }

    public String getBalance() {
        return balance;
    }

    public void setBalance(String balance) {
        this.balance = balance;
    }

    public Integer getBindType() {
        return bindType;
    }

    public void setBindType(Integer bindType) {
        this.bindType = bindType;
    }

    public String getLevelCode() {
        return levelCode;
    }

    public void setLevelCode(String levelCode) {
        this.levelCode = levelCode;
    }

    public String getOfflineCardNo() {
        return offlineCardNo;
    }

    public void setOfflineCardNo(String offlineCardNo) {
        this.offlineCardNo = offlineCardNo;
    }

    public Integer getCountIntegral() {
        return countIntegral;
    }

    public void setCountIntegral(Integer countIntegral) {
        this.countIntegral = countIntegral;
    }

    public String getEffectiveTime() {
        return effectiveTime;
    }

    public void setEffectiveTime(String effectiveTime) {
        this.effectiveTime = effectiveTime;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Integer getGender() {
        return gender;
    }

    public void setGender(Integer gender) {
        this.gender = gender;
    }

    public String getBirthday() {
        return birthday;
    }

    public void setBirthday(String birthday) {
        this.birthday = birthday;
    }

    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }

    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }

    public String getCounty() {
        return county;
    }

    public void setCounty(String county) {
        this.county = county;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getOpenStoreCode() {
        return openStoreCode;
    }

    public void setOpenStoreCode(String openStoreCode) {
        this.openStoreCode = openStoreCode;
    }

    public String getOpenGuideCode() {
        return openGuideCode;
    }

    public void setOpenGuideCode(String openGuideCode) {
        this.openGuideCode = openGuideCode;
    }

    public Integer getFirstLandingCheck() {
        return firstLandingCheck;
    }

    public void setFirstLandingCheck(Integer firstLandingCheck) {
        this.firstLandingCheck = firstLandingCheck;
    }

    public String getErpId() {
        return erpId;
    }

    public void setErpId(String erpId) {
        this.erpId = erpId;
    }

    public String getOpenCardTime() {
        return openCardTime;
    }

    public void setOpenCardTime(String openCardTime) {
        this.openCardTime = openCardTime;
    }
}
